@@ -244,14 +244,11 @@ def _PrintResult(component_trace, verbose=False):
   # and move serialization to its own module.
   result = component_trace.GetResult()
 
-  if hasattr(result, '__str__'):
+  if value_types.HasCustomStr(result):
     # If the object has a custom __str__ method, rather than one inherited from
     # object, then we use that to serialize the object.
-    class_attrs = completion.GetClassAttrsDict(type(result)) or {}
-    str_attr = class_attrs.get('__str__')
-    if str_attr and str_attr.defining_class is not object:
-      print(str(result))
-      return
+    print(str(result))
+    return
 
   if isinstance(result, (list, set, frozenset, types.GeneratorType)):
     for i in result:
@@ -312,7 +309,7 @@ def _DictAsString(result, verbose=False):
   # We need to do 2 iterations over the items in the result dict
   # 1) Getting visible items and the longest key for output formatting
   # 2) Actually construct the output lines
-  class_attrs = completion.GetClassAttrsDict(result)
+  class_attrs = inspectutils.GetClassAttrsDict(result)
   result_visible = {
       key: value for key, value in result.items()
       if completion.MemberVisible(result, key, value,
@@ -632,7 +629,7 @@ def _GetMember(component, args):
   Raises:
     FireError: If we cannot consume an argument to get a member.
   """
-  members = dict(inspect.getmembers(component))
+  members = dir(component)
   arg = args[0]
   arg_names = [
       arg,
@@ -641,7 +638,7 @@ def _GetMember(component, args):
 
   for arg_name in arg_names:
     if arg_name in members:
-      return members[arg_name], [arg], args[1:]
+      return getattr(component, arg_name), [arg], args[1:]
 
   raise FireError('Could not consume arg:', arg)
 
