@@ -149,6 +149,7 @@ def parse(docstring):
 
   Args:
     docstring: The docstring to parse.
+
   Returns:
     A DocstringInfo containing information about the docstring.
   """
@@ -175,8 +176,9 @@ def parse(docstring):
 
   for index, line in enumerate(lines):
     has_next = index + 1 < lines_len
+    previous_line = lines[index - 1] if index > 0 else None
     next_line = lines[index + 1] if has_next else None
-    line_info = _create_line_info(line, next_line)
+    line_info = _create_line_info(line, next_line, previous_line)
     _consume_line(line_info, state)
 
   summary = ' '.join(state.summary.lines) if state.summary.lines else None
@@ -212,7 +214,8 @@ def _strip_blank_lines(lines):
   """
   # Find the first non-blank line.
   start = 0
-  while lines and _is_blank(lines[start]):
+  num_lines = len(lines)
+  while lines and start < num_lines and _is_blank(lines[start]):
     start += 1
 
   lines = lines[start:]
@@ -453,7 +456,7 @@ def _consume_line(line_info, state):
         # of the previous arg, or a new arg. TODO: Whitespace can distinguish.
         arg = _get_or_create_arg_by_name(state, line_stripped)
         state.current_arg = arg
-      elif ':' in line_stripped:
+      elif _line_is_numpy_parameter_type(line_info):
         possible_args, type_data = line_stripped.split(':', 1)
         arg_names = _as_arg_names(possible_args)  # re.split(' |,', s)
         if arg_names:
@@ -490,8 +493,8 @@ def _consume_line(line_info, state):
       pass
 
 
-def _create_line_info(line, next_line):
-  """Returns information about the current and next line of the docstring."""
+def _create_line_info(line, next_line, previous_line):
+  """Returns information about the current line and surrounding lines."""
   line_info = Namespace()  # TODO(dbieber): Switch to an explicit class.
   line_info.line = line
   line_info.stripped = line.strip()
@@ -504,6 +507,11 @@ def _create_line_info(line, next_line):
   line_info.next.stripped = next_line.strip() if next_line_exists else None
   line_info.next.indentation = (
       len(next_line) - len(next_line.lstrip()) if next_line_exists else None)
+  line_info.previous.line = previous_line
+  previous_line_exists = previous_line is not None
+  line_info.previous.indentation = (
+      len(previous_line) -
+      len(previous_line.lstrip()) if previous_line_exists else None)
   # Note: This counts all whitespace equally.
   return line_info
 
@@ -724,3 +732,29 @@ def _numpy_section(line_info):
     return _section_from_possible_title(possible_title)
   else:
     return None
+
+
+def _line_is_numpy_parameter_type(line_info):
+  """Returns whether the line contains a numpy style parameter type definition.
+
+  We look for a line of the form:
+  x : type
+
+  And we have to exclude false positives on argument descriptions containing a
+  colon by checking the indentation of the line above.
+
+  Args:
+    line_info: Information about the current line.
+  Returns:
+    True if the line is a numpy parameter type definition, False otherwise.
+  """
+  line_stripped = line_info.remaining.strip()
+  if ':' in line_stripped:
+    previous_indent = line_info.previous.indentation
+    current_indent = line_info.indentation
+    if ':' in line_info.previous.line and current_indent > previous_indent:
+      # The parameter type was the previous line; this is the description.
+      return False
+    else:
+      return True
+  return False
