@@ -20,7 +20,6 @@ from __future__ import print_function
 
 import os
 import sys
-import unittest
 
 import fire
 from fire import test_components as tc
@@ -185,7 +184,7 @@ class FireTest(testutils.BaseTestCase):
     self.assertEqual(fire.Fire(tc.Annotations, command=['double', '5']), 10)
     self.assertEqual(fire.Fire(tc.Annotations, command=['triple', '5']), 15)
 
-  @unittest.skipIf(six.PY2, 'Keyword-only arguments not in Python 2.')
+  @testutils.skipIf(six.PY2, 'Keyword-only arguments not in Python 2.')
   def testFireKeywordOnlyArgs(self):
     with self.assertRaisesFireExit(2):
       # Keyword arguments must be passed with flag syntax.
@@ -703,6 +702,25 @@ class FireTest(testutils.BaseTestCase):
     with self.assertRaisesFireExit(2):
       fire.Fire(tc.InstanceVars, command=['--arg1=a1', '--arg2=a2', '-', 'jog'])
 
+  def testClassWithDefaultMethod(self):
+    self.assertEqual(
+        fire.Fire(tc.DefaultMethod, command=['double', '10']), 20
+    )
+
+  def testClassWithInvalidProperty(self):
+    self.assertEqual(
+        fire.Fire(tc.InvalidProperty, command=['double', '10']), 20
+    )
+
+  @testutils.skipIf(sys.version_info[0:2] <= (3, 4),
+                    'Cannot inspect wrapped signatures in Python 2 or 3.4.')
+  def testHelpKwargsDecorator(self):
+    # Issue #190, follow the wrapped method instead of crashing.
+    with self.assertRaisesFireExit(0):
+      fire.Fire(tc.decorated_method, command=['-h'])
+    with self.assertRaisesFireExit(0):
+      fire.Fire(tc.decorated_method, command=['--help'])
+
 
 if __name__ == '__main__':
   testutils.main()
