@@ -33,6 +33,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import itertools
+
 from fire import completion
 from fire import custom_descriptions
 from fire import decorators
@@ -41,10 +43,11 @@ from fire import inspectutils
 from fire import value_types
 
 LINE_LENGTH = 80
+SECTION_INDENTATION = 4
 
 
 def HelpText(component, trace=None, verbose=False):
-  """Gets the help string for the current component, suitalbe for a help screen.
+  """Gets the help string for the current component, suitable for a help screen.
 
   Args:
     component: The component to construct the help string for.
@@ -96,10 +99,12 @@ def _NameSection(component, info, trace=None, verbose=False):
   current_command = _GetCurrentCommand(trace, include_separators=verbose)
   summary = _GetSummary(info)
 
-  # If the docstring is one of the messy builtin docstrings, don't show summary.
-  # TODO(dbieber): In follow up commits we can add in replacement summaries.
+  # If the docstring is one of the messy builtin docstrings, show custom one.
   if custom_descriptions.NeedsCustomDescription(component):
-    summary = None
+    available_space = LINE_LENGTH - SECTION_INDENTATION - len(current_command +
+                                                              ' - ')
+    summary = custom_descriptions.GetSummary(component, available_space,
+                                             LINE_LENGTH)
 
   if summary:
     text = current_command + ' - ' + summary
@@ -147,21 +152,28 @@ def _DescriptionSection(component, info):
     Returns the description if available. If not, returns the summary.
     If neither are available, returns None.
   """
-  # If the docstring is one of the messy builtin docstrings, set it to None.
-  # TODO(dbieber): In follow up commits we can add in replacement docstrings.
   if custom_descriptions.NeedsCustomDescription(component):
-    return None
-
-  summary = _GetSummary(info)
-  description = _GetDescription(info)
+    available_space = LINE_LENGTH - SECTION_INDENTATION
+    description = custom_descriptions.GetDescription(component, available_space,
+                                                     LINE_LENGTH)
+    summary = custom_descriptions.GetSummary(component, available_space,
+                                             LINE_LENGTH)
+  else:
+    description = _GetDescription(info)
+    summary = _GetSummary(info)
+  # Fall back to summary if description is not available.
   text = description or summary or None
-
   if text:
     return ('DESCRIPTION', text)
   else:
     return None
 
 
+def _CreateKeywordOnlyFlagItem(flag, docstring_info, spec):
+  return _CreateFlagItem(
+      flag, docstring_info, required=flag not in spec.kwonlydefaults)
+
+
 def _ArgsAndFlagsSections(info, spec, metadata):
   """The "Args and Flags" sections of the help string."""
   args_with_no_defaults = spec.args[:len(spec.args) - len(spec.defaults)]
@@ -194,15 +206,15 @@ def _ArgsAndFlagsSections(info, spec, metadata):
           ('NOTES', 'You can also use flags syntax for POSITIONAL ARGUMENTS')
       )
 
-  optional_flag_items = [
+  positional_flag_items = [
       _CreateFlagItem(flag, docstring_info, required=False)
       for flag in args_with_defaults
   ]
-  required_flag_items = [
-      _CreateFlagItem(flag, docstring_info, required=True)
+  kwonly_flag_items = [
+      _CreateKeywordOnlyFlagItem(flag, docstring_info, spec)
       for flag in spec.kwonlyargs
   ]
-  flag_items = optional_flag_items + required_flag_items
+  flag_items = positional_flag_items + kwonly_flag_items
 
   if spec.varkw:
     description = _GetArgDescription(spec.varkw, docstring_info)
@@ -348,8 +360,9 @@ def _GetCurrentCommand(trace=None, include_separators=True):
 
 def _CreateOutputSection(name, content):
   return """{name}
-{content}""".format(name=formatting.Bold(name),
-                    content=formatting.Indent(content, 4))
+{content}""".format(
+    name=formatting.Bold(name),
+    content=formatting.Indent(content, SECTION_INDENTATION))
 
 
 def _CreateArgItem(arg, docstring_info):
@@ -359,6 +372,7 @@ def _CreateArgItem(arg, docstring_info):
     arg: The name of the positional argument.
     docstring_info: A docstrings.DocstringInfo namedtuple with information about
       the containing function's docstring.
+
   Returns:
     A string to be used in constructing the help screen for the function.
   """
@@ -375,9 +389,7 @@ def _CreateFlagItem(flag, docstring_info, required=False):
     flag: The name of the flag.
     docstring_info: A docstrings.DocstringInfo namedtuple with information about
       the containing function's docstring.
-    required: Whether the flag is required. Keyword-only arguments (only in
-      Python 3) become required flags, whereas normal keyword arguments become
-      optional flags.
+    required: Whether the flag is required.
   Returns:
     A string to be used in constructing the help screen for the function.
   """
@@ -418,6 +430,9 @@ def _MakeUsageDetailsSection(action_group):
     if (docstring_info
         and not custom_descriptions.NeedsCustomDescription(member)):
       summary = docstring_info.summary
+    elif custom_descriptions.NeedsCustomDescription(member):
+      summary = custom_descriptions.GetSummary(
+          member, LINE_LENGTH - SECTION_INDENTATION, LINE_LENGTH)
     else:
       summary = None
     item = _CreateItem(name, summary)
@@ -560,13 +575,21 @@ def _GetCallableUsageItems(spec, metadata):
   return items
 
 
+def _KeywordOnlyArguments(spec, required=True):
+  return (flag for flag in spec.kwonlyargs
+          if required == (flag in spec.kwonlydefaults))
+
+
 def _GetCallableAvailabilityLines(spec):
   """The list of availability lines for a callable for use in a usage string."""
   args_with_defaults = spec.args[len(spec.args) - len(spec.defaults):]
 
   # TODO(dbieber): Handle args_with_no_defaults if not accepts_positional_args.
-  optional_flags = [('--' + flag) for flag in args_with_defaults]
-  required_flags = [('--' + flag) for flag in spec.kwonlyargs]
+  optional_flags = [('--' + flag) for flag in itertools.chain(
+      args_with_defaults, _KeywordOnlyArguments(spec, required=False))]
+  required_flags = [
+      ('--' + flag) for flag in _KeywordOnlyArguments(spec, required=True)
+  ]
 
   # Flags section:
   availability_lines = []
