@@ -12,9 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# Lint as: python3
 """This module has components that use Python 3 specific syntax."""
 
+import functools
 
+
+# pylint: disable=keyword-arg-before-vararg
 def identity(arg1, arg2: int, arg3=10, arg4: int = 20, *arg5,
              arg6, arg7: int, arg8=30, arg9: int = 40, **arg10):
   return arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10
@@ -27,3 +31,18 @@ class KeywordOnly(object):
 
   def triple(self, *, count):
     return count * 3
+
+  def with_default(self, *, x="x"):
+    print("x: " + x)
+
+
+class LruCacheDecoratedMethod(object):
+
+  @functools.lru_cache()
+  def lru_cache_in_class(self, arg1):
+    return arg1
+
+
+@functools.lru_cache()
+def lru_cache_decorated(arg1):
+  return arg1
